@@ -4,8 +4,8 @@ use 5.010001;
 use strict;
 use warnings;
 
-our $VERSION = '0.29'; # VERSION
-our $DATE = '2014-11-17'; # DATE
+our $VERSION = '0.30'; # VERSION
+our $DATE = '2014-11-28'; # DATE
 
 our $_complete_module = sub {
     require Complete::Module;
@@ -24,7 +24,7 @@ our $_complete_module = sub {
     $word =~ s/\W+/::/g;
 
     {
-        completion => Complete::Module::complete_module(
+        words => Complete::Module::complete_module(
             word      => $word,
             find_pmc  => 0,
             find_pod  => 0,
@@ -45,7 +45,7 @@ our $_complete_pod = sub {
     $word =~ s/\W+/::/g;
 
     {
-        completion => Complete::Module::complete_module(
+        words => Complete::Module::complete_module(
             word      => $word,
             find_pm   => 0,
             find_pmc  => 0,
@@ -72,7 +72,7 @@ App::PMUtils - Command-line utilities related to Perl modules
 
 =head1 VERSION
 
-This document describes version 0.29 of App::PMUtils (from Perl distribution App-PMUtils), released on 2014-11-17.
+This document describes version 0.30 of App::PMUtils (from Perl distribution App-PMUtils), released on 2014-11-28.
 
 =head1 SYNOPSIS
 
